# Changelog

<!--next-version-placeholder-->

## v1.1.0 (2022-08-27)
### Feature
* Make it work on macos ([#2](https://github.com/bdraco/protobuf-wheel-builder/issues/2)) ([`09976bf`](https://github.com/bdraco/protobuf-wheel-builder/commit/09976bfb369fa79da32bfdf63b8465894a9d319d))
* Init repo ([`a34e181`](https://github.com/bdraco/protobuf-wheel-builder/commit/a34e181c849ee4a6ea70cdc07f85d649b2a8cbca))
* Init repo ([`0319334`](https://github.com/bdraco/protobuf-wheel-builder/commit/0319334a1165841e4e80b2f728fece20f242c6b4))

### Fix
* Build ([`ea8865d`](https://github.com/bdraco/protobuf-wheel-builder/commit/ea8865dd067a93261a0eec66910a54dad59fefa7))
* Build ([`f98b14d`](https://github.com/bdraco/protobuf-wheel-builder/commit/f98b14d2cfab75fe67e691cc9b950119c91a7cac))

## v3.21.0 (2022-08-27)
### Feature
* Make it work on macos ([#2](https://github.com/bdraco/protobuf-wheel-builder/issues/2)) ([`09976bf`](https://github.com/bdraco/protobuf-wheel-builder/commit/09976bfb369fa79da32bfdf63b8465894a9d319d))
* Init repo ([`a34e181`](https://github.com/bdraco/protobuf-wheel-builder/commit/a34e181c849ee4a6ea70cdc07f85d649b2a8cbca))
* Init repo ([`0319334`](https://github.com/bdraco/protobuf-wheel-builder/commit/0319334a1165841e4e80b2f728fece20f242c6b4))
